/*  $Id: TestCache.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import java.util.Hashtable;
import org.junit.*;
import static org.junit.Assert.*;
import java.util.Random;

import net.eduvax.util.Cache;
import net.eduvax.util.DataSource;


public class TestCache {
	final static int DATACOUNT=10;
	final static int CACHESIZE=5;
	final static int GETCOUNT=100;

	private TestDataSource<String,String> _ds;
	private Cache<String,String> _cache;
    @Before public void setUp() {
		_ds=new TestDataSource<String,String>();
		for (int i=0;i<DATACOUNT;i++) {
			_ds.put(""+i,""+i);
		}	
		_cache=new Cache<String,String>(CACHESIZE,_ds);
    }
    @After public void tearDown() {
    }

    @Test public void testCache() {
		Random r=new Random();
		for (int i=0;i<GETCOUNT;i++) {
			String str=""+r.nextInt(DATACOUNT);
			assertTrue(str.equals(_cache.get(str)));
		}
		assertTrue(_ds.getGetCount()<GETCOUNT);
		System.out.println("Datasource access : "+_ds.getGetCount()+"/"+GETCOUNT);
    }

	public class TestDataSource<K,V> implements DataSource<K,V> {
		public V get(K key) {
			_getCount++;
			return _table.get(key);
		}	
        public void put(K key,V value) {
            _table.put(key,value);
        }
		private int _getCount=0;
        public int getGetCount() {
            return _getCount;
        }
        private Hashtable<K,V> _table=new Hashtable<K,V>();
	}
}        
